@@ -7,7 +7,7 @@ use Mojo::URL;
 
 use Getopt::Long qw(GetOptionsFromArray);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has description => 'Quick reference tool for the reddit API';
 
@@ -73,8 +73,10 @@ sub _get_info {
 
     my $desc = $container->find('.md p')->map(
         sub {
-            ## keep a bit of identation for output
-            return ' ' . $_->text unless $_->text =~ /\bSee also\b/;
+            unless ($_->text =~ /\bSee also\b/) {
+                $_->find('*')->map('strip');    # get all text available
+                return ' ' . $_->text;
+            }
 
             # use strip() instead?
             return 'See also: ', $_->find('a')->map(
